-- ┌                                               ┐
-- │                Web technology                 │
-- └                                               ┘
local lsp = vim.lsp

local capabilities = require("lsp-options").capabilities
local on_attach = require("lsp-options").on_attach

-- ┌                                               ┐
-- │                HTML, CSS, JSON                │
-- └                                               ┘
lsp.config("cssls", {
    capabilities = capabilities,
    on_attach = on_attach,
})

lsp.config("html", {
    capabilities = capabilities,
    on_attach = on_attach,
})

lsp.config("jsonls", {
    capabilities = capabilities,
    on_attach = on_attach,
})

-- ┌                                               ┐
-- │                      Vue                      │
-- └                                               ┘
lsp.config("vue_ls", {
    capabilities = capabilities,
    on_attach = on_attach,
    filetypes = {
        "vue",
    },
})

-- ┌                                               ┐
-- │               TS, JS, TSX, JSX                │
-- └                                               ┘
lsp.config("ts_ls", {
    capabilities = capabilities,
    on_attach = on_attach,
    init_options = {
        plugins = {
            {
                name = "@vue/typescript-plugin",
                location = "/usr/lib/node_modules/@vue/typescript-plugin",
                languages = { "javascript", "typescript", "vue" },
            },
        },
    },
    filetypes = {
        "javascript",
        "typescript",
        "typescriptreact",
        "javascriptreact",
        "vue",
    },
})


-- ── Enable configs ───────────────────────────────────────────────
local enable = vim.lsp.enable
enable("jsonls")
enable("html")
enable("css")
enable("vue_ls")
enable("ts_ls")
